%define nspr_name       dirsec-nspr
%define nspr_version    4.6
%define nss_name        dirsec-nss
%define nss_version     3.11
%define svrcore_name    svrcore
%define svrcore_version 4.0.3
%define major           6
%define minor           0
%define submin          5
%define libsuffix       %{major}0
%define myname          mozldap%{major}
%define incdir          %{_includedir}/%{myname}
%define mybindir        %{_libdir}/%{myname}
%define mydatadir       %{_datadir}/%{myname}

Summary:          Mozilla LDAP C SDK
Name:             %{myname}
Version:          %{major}.%{minor}.%{submin}
Release:          1el4idm
License:          MPL/GPL/LGPL
URL:              http://www.mozilla.org/directory/csdk.html
Group:            System Environment/Libraries
Requires:         %{nspr_name} >= %{nspr_version}
Requires:         %{nss_name} >= %{nss_version}
Requires:         %{svrcore_name} >= %{nss_version}
Requires:	      cyrus-sasl
BuildRoot:        %{_tmppath}/%{myname}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:    %{nspr_name}-devel >= %{nspr_version}
BuildRequires:    %{nss_name}-devel >= %{nss_version}
BuildRequires:    %{svrcore_name}-devel >= %{svrcore_version}
BuildRequires:	  cyrus-sasl-devel
ExclusiveArch:    i386 x86_64

Source0:          ftp://ftp.mozilla.org/pub/mozilla.org/directory/c-sdk/releases/v%{version}/src/mozldap-%{version}.tar.gz
Source1:          mozldap_command_wrapper

%description
The Mozilla LDAP C SDK is a set of libraries that
allow applications to communicate with LDAP directory
servers.  These libraries are derived from the University
of Michigan and Netscape LDAP libraries.  They use Mozilla
NSPR and NSS for crypto.


%package tools
Summary:          Tools for the Mozilla LDAP C SDK
Group:            System Environment/Base
Requires:         %{name} = %{version}-%{release}
BuildRequires:    %{nspr_name}-devel >= %{nspr_version}
BuildRequires:    %{nss_name}-devel >= %{nss_version}
BuildRequires:    %{svrcore_name}-devel >= %{svrcore_version}

%description tools
The mozldap-tools package provides the ldapsearch,
ldapmodify, and ldapdelete tools that use the
Mozilla LDAP C SDK libraries.


%package devel
Summary:          Development libraries and examples for Mozilla LDAP C SDK
Group:            Development/Libraries
Requires:         %{name} = %{version}-%{release}
Requires:         %{nspr_name}-devel >= %{nspr_version}
Requires:         %{nss_name}-devel >= %{nss_version}
Requires:         %{svrcore_name}-devel >= %{svrcore_version}
Requires:         pkgconfig

%description devel
Headers, examples, and other files for doing development with the Mozilla LDAP C SDK

%prep
%setup -q -n mozldap-%{version}

%build
%ifarch x86_64 ppc64 ia64 s390x
arg64="--enable-64bit"
%endif

# get nspr locations
NSPR_INCLUDE_DIR=`/usr/bin/pkg-config --variable=includedir %{nspr_name}`
NSPR_LIB_DIR=`/usr/bin/pkg-config --variable=libdir %{nspr_name}`

# get nss locations
NSS_INCLUDE_DIR=`/usr/bin/pkg-config --variable=includedir %{nss_name}`
NSS_LIB_DIR=`/usr/bin/pkg-config --variable=libdir %{nss_name}`

cd mozilla/directory/c-sdk
%configure $arg64 --enable-clu --with-system-svrcore --with-sasl \
	--enable-optimize --disable-debug \
	--with-nspr-inc="$NSPR_INCLUDE_DIR" \
	--with-nspr-lib="$NSPR_LIB_DIR" \
	--with-nss-inc="$NSS_INCLUDE_DIR" \
	--with-nss-lib="$NSS_LIB_DIR"

# Enable compiler optimizations and disable debugging code
BUILD_OPT=1
export BUILD_OPT

# Generate symbolic info for debuggers
XCFLAGS="$RPM_OPT_FLAGS"
export XCFLAGS

%ifarch x86_64 ppc64 ia64 s390x
USE_64=1
export USE_64
%endif

make

%install
if [ $RPM_BUILD_ROOT != "/" ] ; then %{__rm} -rf $RPM_BUILD_ROOT ; fi

# Set up our package file
%{__mkdir_p} $RPM_BUILD_ROOT%{_libdir}/pkgconfig
%{__cat} mozilla/directory/c-sdk/mozldap.pc.in | sed -e "s,%%libdir%%,%{_libdir},g" \
                          -e "s,%%prefix%%,%{_prefix},g" \
                          -e "s,%%major%%,%{major},g" \
                          -e "s,%%minor%%,%{minor},g" \
                          -e "s,%%submin%%,%{submin},g" \
                          -e "s,%%libsuffix%%,%{libsuffix},g" \
                          -e "s,%%bindir%%,%{mybindir},g" \
                          -e "s,%%exec_prefix%%,%{_prefix},g" \
                          -e "s,%%includedir%%,%{incdir},g" \
                          -e "s,\<nspr\>,%{nspr_name},g" \
                          -e "s,\<nss\>,%{nss_name},g" \
                          -e "s,%%NSPR_VERSION%%,%{nspr_version},g" \
                          -e "s,%%NSS_VERSION%%,%{nss_version},g" \
                          -e "s,%%SVRCORE_VERSION%%,%{svrcore_version},g" \
                          -e "s,%%MOZLDAP_VERSION%%,%{version},g" > \
                          $RPM_BUILD_ROOT%{_libdir}/pkgconfig/%{myname}.pc

# There is no make install target so we'll do it ourselves.

%{__mkdir_p} $RPM_BUILD_ROOT%{incdir}
%{__mkdir_p} $RPM_BUILD_ROOT%{mybindir}

# Copy the binary libraries we want
for file in libssldap%{libsuffix}.so libprldap%{libsuffix}.so libldap%{libsuffix}.so libldif%{libsuffix}.so
do
  %{__install} -m 755 mozilla/dist/lib/$file $RPM_BUILD_ROOT%{_libdir}
done

# if NSPR and NSS are not installed in the standard system library places,
# we need to create shell script wrappers around the command line tools
# so that their LD_LIBRARY_PATH and PATH are set correctly to find these
# tools - basically, if nsprlibdir != _libdir or nsslibdir != _libdir, we
# have to create the wrappers
create_wrapper()
{
  LIB_DIR="$1"
  BIN_DIR="$2"
  COMMAND="$3"

  WRAPPER="$RPM_BUILD_ROOT%{mybindir}/${COMMAND}"

  sed     -e "s|\[LIB_DIR\]|${LIB_DIR}|g" \
          -e "s|\[BIN_DIR\]|${BIN_DIR}|g" \
          -e "s|\[COMMAND\]|${COMMAND}|g" \
          "%{SOURCE1}" > "${WRAPPER}"
  chmod 755 "${WRAPPER}"
}


NSPR_LIB_DIR=`/usr/bin/pkg-config --variable=libdir %{nspr_name}`
NSS_LIB_DIR=`/usr/bin/pkg-config --variable=libdir %{nss_name}`

if test -n "$NSPR_LIB_DIR" -a "$NSPR_LIB_DIR" != "%{_libdir}" ; then
  CMDLIBPATH="$NSPR_LIB_DIR"
fi
if test -n "$NSS_LIB_DIR" -a "$NSS_LIB_DIR" != "%{_libdir}" -a "$NSPR_LIB_DIR" != "$NSS_LIB_DIR"; then
  if [ "$CMDLIBPATH" ] ; then
    CMDLIBPATH="${CMDLIBPATH}:$NSS_LIB_DIR"
  else
    CMDLIBPATH="$NSS_LIB_DIR"
  fi
fi

# Copy the binaries we want
if [ "$CMDLIBPATH" ] ; then
  binsuffix="-bin"
fi
for file in ldapsearch ldapmodify ldapdelete ldapcmp ldapcompare ldappasswd
do
# create the binary file with a -bin suffix if we need to wrap them
  %{__install} -m 755 mozilla/dist/bin/$file $RPM_BUILD_ROOT%{mybindir}/${file}$binsuffix
  if [ "$binsuffix" ] ; then
    create_wrapper "$CMDLIBPATH" "${CMDLIBPATH}:%{mybindir}" "$file"
  fi
done

# Copy the include files
for file in mozilla/dist/public/ldap/*.h
do
  %{__install} -m 644 $file $RPM_BUILD_ROOT%{incdir}
done

# Copy the developer files
%{__mkdir_p} $RPM_BUILD_ROOT%{mydatadir}
cp -r mozilla/directory/c-sdk/ldap/examples $RPM_BUILD_ROOT%{mydatadir}
%{__mkdir_p} $RPM_BUILD_ROOT%{mydatadir}/etc
%{__install} -m 644 mozilla/directory/c-sdk/ldap/examples/xmplflt.conf $RPM_BUILD_ROOT%{mydatadir}/etc
%{__install} -m 644 mozilla/directory/c-sdk/ldap/libraries/libldap/ldaptemplates.conf $RPM_BUILD_ROOT%{mydatadir}/etc
%{__install} -m 644 mozilla/directory/c-sdk/ldap/libraries/libldap/ldapfilter.conf $RPM_BUILD_ROOT%{mydatadir}/etc
%{__install} -m 644 mozilla/directory/c-sdk/ldap/libraries/libldap/ldapsearchprefs.conf $RPM_BUILD_ROOT%{mydatadir}/etc

%clean
if [ $RPM_BUILD_ROOT != "/" ] ; then %{__rm} -rf $RPM_BUILD_ROOT ; fi


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc mozilla/directory/c-sdk/README.rpm
%{_libdir}/libssldap%{libsuffix}.so
%{_libdir}/libprldap%{libsuffix}.so
%{_libdir}/libldap%{libsuffix}.so
%{_libdir}/libldif%{libsuffix}.so

%files tools
%defattr(-,root,root,-)
%dir %{mybindir}
%{mybindir}/ldapsearch-bin
%{mybindir}/ldapmodify-bin
%{mybindir}/ldapdelete-bin
%{mybindir}/ldapcmp-bin
%{mybindir}/ldapcompare-bin
%{mybindir}/ldappasswd-bin
%{mybindir}/ldapsearch
%{mybindir}/ldapmodify
%{mybindir}/ldapdelete
%{mybindir}/ldapcmp
%{mybindir}/ldapcompare
%{mybindir}/ldappasswd

%files devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/%{myname}.pc
%{incdir}
%{mydatadir}

%changelog
* Wed Sep 26 2007 Noriko Hosoi <nhosoi@redhat.com> - 6.0.5-1el4idm
- bump rev to 6.0.5

* Wed Jul 25 2007 Rich Megginson <rmeggins@redhat.com> - 6.0.4-1el4idm
- bump rev to 6.0.4

* Thu Jun 07 2007 Margaret Lum <mlum@redhat.com> - 6.0.2-1el4idm
- Adding hard-coded disttag for el4idm

* Mon Jan 15 2007 Rich Megginson <rmeggins@redhat.com> - 6.0.2-1
- Imported 6.0.2 sources - this version fixes Solaris & Windows
- shared library export file definitions - no difference on linux
- these are the sources imported into fedora extras

* Thu Jan 11 2007 Rich Megginson <rmeggins@redhat.com> - 6.0.1-1
- Imported 6.0.1 sources - 6.0.1 exports libldif as part of the the
- public API

* Fri Oct 20 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-14
- cyrus-sasl-lib is called cyrus-sasl on RHEL4

* Thu Oct 19 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-13
- add sasl as a dependency - not sure why this worked without it

* Thu Oct 19 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-12
- add .a files to the devel package

* Thu Oct 19 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-11
- add ldif.h to the include files

* Tue Oct 17 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-10
- make wrapper scripts executable

* Tue Oct 17 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-9
- try to figure out why wrappers are not being created

* Mon Oct 16 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-8
- pkgconfig file has to be called mozldap6.pc

* Mon Oct 16 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-7
- have to use dirsec-nspr and dirsec-nss in pkgconfig file

* Wed Oct 11 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-6
- upgrade to real final rtm version of mozldap6

* Tue Oct 10 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-5
- upgrade to final rtm version of mozldap6
- this version finds sasl in the right place

* Fri Oct  6 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-4
- tell configure to look for sasl in /usr/include/sasl

* Fri Oct  6 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-3
- only build on x86 and x86_64

* Fri Oct  6 2006 Rich Megginson <rmeggins@redhat.com> - 6.0.0-2
- Use dirsec-nspr and dirsec-nss ; create wrapper scripts since dirsec-nspr
- and dirsec-nss are not installed in the system lib path

* Thu Oct  5 2006 Rich Megginson <richm@stanforalumni.org> - 6.0.0-1
- Bump version to 6.0.0 - add support for submit/patch level (3rd level) in version numbering

* Tue Apr 18 2006 Richard Megginson <richm@stanforalumni.org> - 5.17-3
- make more Fedora Core friendly - move each requires and buildrequires to a separate line
- remove --with-nss since svrcore implies it; fix some macro errors; macro-ize nspr and nss names
- fix directory attrs in devel package

* Tue Jan 31 2006 Rich Megginson <rmeggins@redhat.com> - 5.17-2
- use --with-system-svrcore to configure

* Mon Dec 19 2005 Rich Megginson <rmeggins@redhat.com> - 5.17-1
- Initial revision

